Learn R Programming

nifffty (version 0.1.1.9000)

ifttt_api_key: Get or set IFTTT_KEY value

Description

The API wrapper functions in this package all rely on an IFTTT API key residing in the environment variable IFTTT_API_KEY. The easiest way to accomplish this is to set it in the `.Renviron` file in your home directory.

Usage

ifttt_api_key(force = FALSE)

Arguments

force
force setting a new IFTTT API key for the current environment?

Value

atomic character vector containing the IFTTT API key