Learn R Programming

nifffty (version 0.1.1.9000)

maker: Issue IFTTT maker channel POST event

Description

You must have an IFTTT account and an event trigget setup with an IFTTT Maker channel. See this post for more information and a full example.

Usage

maker(event = NULL, value1 = NULL, value2 = NULL, value3 = NULL)

Arguments

event
event name to trigger in IFTTT recipe
value1
event parameter (optional)
value2
event parameter (optional)
value3
event parameter (optional)

See Also

http://bconnelly.net/2015/06/connecting-r-to-everything-with-ifttt/